@@ -1,9 +1,9 @@
 package BenchmarkAnything::Storage::Backend::SQL;
-# git description: v0.020-21-g75efc23
+# git description: v0.021-3-gdfc449c
 
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Autonomous SQL backend to store benchmarks
-$BenchmarkAnything::Storage::Backend::SQL::VERSION = '0.021';
+$BenchmarkAnything::Storage::Backend::SQL::VERSION = '0.022';
 use 5.008;
 use utf8;
 use strict;
@@ -729,9 +729,9 @@ sub search_array {
         require Data::Dumper;
         print STDERR ',-------------------'."\n";
         print STDERR "benchmarkanything query:\n";
-        print STDERR "echo '\n";
+        print STDERR "benchmarkanything-storage search -d '\n";
         print STDERR JSON::XS->new->pretty->encode($hr_search);
-        print STDERR "' | benchmarkanything-storage search\n";
+        print STDERR "'\n";
         print STDERR '`-------------------'."\n";
     }
 
@@ -1033,21 +1033,17 @@ sub init_search_engine
         # mappings
         my $mappings =
         {
-          $s_type => { properties => {
-                                     NAME       => { type         => 'keyword',
-                                                     store        => json_true,
-                                                   },
-                                     VALUE      => { type         => 'text',
-                                                   },
-                                     VALUE_ID   => { type         => 'long',
-                                                   },
-                                     UNIT       => { type         => 'text',
-                                                   },
-                                     CREATED    => { type         => 'date',
-                                                     format       => 'yyyy-MM-dd||yyyy-MM-dd HH:mm:ss',
-                                                   },
-                                    }
-                    },
+         $s_type => {
+          dynamic_templates =>
+          [
+           { "core_field_NAME"     => { "match" => "NAME",     "mapping" => { "type" => "keyword", "store" => json_true } } },
+           { "core_field_VALUE"    => { "match" => "VALUE",    "mapping" => { "type" => "text", } } },
+           { "core_field_UNIT"     => { "match" => "UNIT",     "mapping" => { "type" => "text", } } },
+           { "core_field_VALUE_ID" => { "match" => "VALUE_ID", "mapping" => { "type" => "long", } } },
+           { "core_field_CREATED"  => { "match" => "CREATED",  "mapping" => { "type" => "date", format => 'yyyy-MM-dd||yyyy-MM-dd HH:mm:ss', } } },
+           { "non_core_fields"     => { "match" => "*",        "mapping" => { "type" => "keyword", } } },
+          ]
+         }
         };
         require JSON::XS;
         require Hash::Merge;
